@@ -3,7 +3,7 @@
 |''Description''|adaptor for interacting with TiddlyWeb|
 |''Author:''|FND|
 |''Contributors''|Chris Dent, Martin Budden|
-|''Version''|1.4.0|
+|''Version''|1.4.3|
 |''Status''|stable|
 |''Source''|http://svn.tiddlywiki.org/Trunk/association/adaptors/TiddlyWebAdaptor.js|
 |''CodeRepository''|http://svn.tiddlywiki.org/Trunk/association/|
@@ -119,7 +119,7 @@ adaptor.getTiddlerListCallback = function(status, context, responseText, uri, xh
 			return;
 		}
 		for(var i = 0; i < tiddlers.length; i++) {
-			var tiddler = context.adaptor.toTiddler(tiddlers[i], context.host);
+			var tiddler = adaptor.toTiddler(tiddlers[i], context.host);
 			context.tiddlers.push(tiddler);
 		}
 	}
@@ -172,7 +172,7 @@ adaptor.getTiddlerRevisionListCallback = function(status, context, responseText,
 			return;
 		}
 		for(var i = 0; i < tiddlers.length; i++) {
-			var tiddler = context.adaptor.toTiddler(tiddlers[i], context.host);
+			var tiddler = adaptor.toTiddler(tiddlers[i], context.host);
 			context.revisions.push(tiddler);
 		}
 		var sortField = "server.page.revision";
@@ -210,10 +210,9 @@ adaptor.prototype.getTiddler = function(title, context, userParams, callback) {
 	context.tiddler.fields["server.type"] = adaptor.serverType;
 	context.tiddler.fields["server.host"] = AdaptorBase.minHostName(context.host);
 	context.tiddler.fields["server.workspace"] = context.workspace;
-	var serverTitle = context.tiddler.fields["server.title"] || title;
 	var workspace = adaptor.resolveWorkspace(context.workspace);
 	var uri = uriTemplate.format([context.host, workspace.type + "s",
-		adaptor.normalizeTitle(workspace.name), adaptor.normalizeTitle(serverTitle),
+		adaptor.normalizeTitle(workspace.name), adaptor.normalizeTitle(title),
 		context.revision]);
 	var req = httpReq("GET", uri, adaptor.getTiddlerCallback, context,
 		merge({ accept: adaptor.mimeType }, context.headers), null, null, null, null, true);
@@ -235,9 +234,10 @@ adaptor.getTiddlerCallback = function(status, context, responseText, uri, xhr) {
 			}
 			return;
 		}
-		var tiddler = context.adaptor.toTiddler(tid, context.host);
+		var tiddler = adaptor.toTiddler(tid, context.host);
 		tiddler.title = context.tiddler.title;
 		tiddler.fields["server.etag"] = xhr.getResponseHeader("Etag");
+		context.tiddler = tiddler;
 	}
 	if(context.callback) {
 		context.callback(context, context.userParams);
@@ -432,6 +432,7 @@ adaptor.prototype.moveTiddler = function(from, to, context, userParams, callback
 		if(!context.status) {
 			return callback(context, userParams);
 		}
+		$.extend(true, newTiddler, context.tiddler);
 		context.callback = null;
 		return self.deleteTiddler(oldTiddler, context, context.userParams, callback);
 	};
@@ -545,11 +546,11 @@ adaptor.prototype.generateTiddlerInfo = function(tiddler) {
 };
 
 // create Tiddler instance from TiddlyWeb tiddler JSON
-adaptor.prototype.toTiddler = function(json, host) {
+adaptor.toTiddler = function(json, host) {
 	var created = Date.convertFromYYYYMMDDHHMM(json.created);
 	var modified = Date.convertFromYYYYMMDDHHMM(json.modified);
 	var fields = json.fields;
-	fields["server.type"] = this.serverType;
+	fields["server.type"] = adaptor.serverType;
 	fields["server.host"] = AdaptorBase.minHostName(host);
 	fields["server.bag"] = json.bag;
 	fields["server.title"] = json.title;
